Index: src/ic/handler-compiler.cc |
diff --git a/src/ic/handler-compiler.cc b/src/ic/handler-compiler.cc |
index ae977c391533a9c18efd88b1cd1201bfcb4b9da8..cab8872a8c78268a15ac42215ee66adbfca2e109 100644 |
--- a/src/ic/handler-compiler.cc |
+++ b/src/ic/handler-compiler.cc |
@@ -270,7 +270,7 @@ void NamedLoadHandlerCompiler::InterceptorVectorSlotPop(Register holder_reg, |
Handle<Code> NamedLoadHandlerCompiler::CompileLoadInterceptor( |
LookupIterator* it) { |
// So far the most popular follow ups for interceptor loads are FIELD and |
// ExecutableAccessorInfo, so inline only them. Other cases may be added |
// later. |
bool inline_followup = false; |
@@ -284,7 +284,7 @@ Handle<Code> NamedLoadHandlerCompiler::CompileLoadInterceptor( |
break; |
case LookupIterator::DATA: |
inline_followup = |
- it->property_details().type() == FIELD && !it->is_dictionary_holder(); |
+ it->property_details().type() == DATA && !it->is_dictionary_holder(); |
break; |
case LookupIterator::ACCESSOR: { |
Handle<Object> accessors = it->GetAccessors(); |
@@ -337,7 +337,7 @@ void NamedLoadHandlerCompiler::GenerateLoadPostInterceptor( |
case LookupIterator::TRANSITION: |
UNREACHABLE(); |
case LookupIterator::DATA: { |
- DCHECK_EQ(FIELD, it->property_details().type()); |
+ DCHECK_EQ(DATA, it->property_details().type()); |
__ Move(receiver(), reg); |
LoadFieldStub stub(isolate(), it->GetFieldIndex()); |
GenerateTailCall(masm(), stub.GetCode()); |
@@ -392,7 +392,7 @@ Handle<Code> NamedStoreHandlerCompiler::CompileStoreTransition( |
DCHECK(!transition->is_access_check_needed()); |
// Call to respective StoreTransitionStub. |
- if (details.type() == CONSTANT) { |
+ if (details.type() == DATA_CONSTANT) { |
GenerateRestoreMap(transition, scratch2(), &miss); |
DCHECK(descriptors->GetValue(descriptor)->IsJSFunction()); |
Register map_reg = StoreTransitionDescriptor::MapRegister(); |
@@ -270,7 +270,7 @@ void NamedLoadHandlerCompiler::InterceptorVectorSlotPop(Register holder_reg, |
Handle<Code> NamedLoadHandlerCompiler::CompileLoadInterceptor( |
LookupIterator* it) { |
- // So far the most popular follow ups for interceptor loads are FIELD and |
+ // So far the most popular follow ups for interceptor loads are DATA and |
// ExecutableAccessorInfo, so inline only them. Other cases may be added |
// later. |